"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    account_id: str,
    cluster_identifier: str,
    database_name: str,
    partner_name: str,
    status: str,
    status_message: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the status of a partner integration.

    Args:
        account_id(str): The Amazon Web Services account ID that owns the cluster.
        cluster_identifier(str): The cluster identifier of the cluster whose partner integration status is being updated.
        database_name(str): The name of the database whose partner integration status is being updated.
        partner_name(str): The name of the partner whose integration status is being updated.
        status(str): The value of the updated status.
        status_message(str, optional): The status message provided by the partner. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.partner.status.update(
                ctx,
                account_id=value,
                cluster_identifier=value,
                database_name=value,
                partner_name=value,
                status=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.partner.status.update account_id=value, cluster_identifier=value, database_name=value, partner_name=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="update_partner_status",
        op_kwargs={
            "AccountId": account_id,
            "ClusterIdentifier": cluster_identifier,
            "DatabaseName": database_name,
            "PartnerName": partner_name,
            "Status": status,
            "StatusMessage": status_message,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    domain: str,
    domain_owner: str = None,
    administrator_account: str = None,
    repository_prefix: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of RepositorySummary objects. Each RepositorySummary contains information about a repository in the specified domain and that matches the input parameters.

    Args:
        domain(str):  The name of the domain that contains the returned list of repositories. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        administrator_account(str, optional):  Filter the list of repositories to only include those that are managed by the AWS account ID. . Defaults to None.
        repository_prefix(str, optional):  A prefix used to filter returned repositories. Only repositories with names that start with repositoryPrefix are returned. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return per page. . Defaults to None.
        next_token(str, optional):  The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.repository.in_domain.list(ctx, domain=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.repository.in_domain.list domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="list_repositories_in_domain",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "administratorAccount": administrator_account,
            "repositoryPrefix": repository_prefix,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information on a specific data ingestion job such as creation time, dataset ARN, status, and so on.

    Args:
        job_id(str): The job ID of the data ingestion job. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.data.ingestion_job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.data.ingestion_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="describe_data_ingestion_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub,
    ctx,
    dataset_name: str = None,
    next_token: str = None,
    max_results: int = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of all data ingestion jobs, including dataset name and ARN, S3 location of the input data, status, and so on.

    Args:
        dataset_name(str, optional): The name of the dataset being used for the data ingestion job. . Defaults to None.
        next_token(str, optional):  An opaque pagination token indicating where to continue the listing of data ingestion jobs. . Defaults to None.
        max_results(int, optional):  Specifies the maximum number of data ingestion jobs to list. . Defaults to None.
        status(str, optional): Indicates the status of the data ingestion job. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.data.ingestion_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.data.ingestion_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="list_data_ingestion_jobs",
        op_kwargs={
            "DatasetName": dataset_name,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Status": status,
        },
    )


async def start(
    hub,
    ctx,
    dataset_name: str,
    ingestion_input_configuration: Dict,
    role_arn: str,
    client_token: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a data ingestion job. Amazon Lookout for Equipment returns the job status.

    Args:
        dataset_name(str): The name of the dataset being used by the data ingestion job. .
        ingestion_input_configuration(Dict):  Specifies information for the input data for the data ingestion job, including dataset S3 location. .
        role_arn(str):  The Amazon Resource Name (ARN) of a role with permission to access the data source for the data ingestion job. .
        client_token(str):  A unique identifier for the request. If you do not set the client request token, Amazon Lookout for Equipment generates one. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.data.ingestion_job.start(
                ctx,
                dataset_name=value,
                ingestion_input_configuration=value,
                role_arn=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.data.ingestion_job.start dataset_name=value, ingestion_input_configuration=value, role_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="start_data_ingestion_job",
        op_kwargs={
            "DatasetName": dataset_name,
            "IngestionInputConfiguration": ingestion_input_configuration,
            "RoleArn": role_arn,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns your gateway's weekly maintenance start time including the day and time of the week. Note that values are in terms of the gateway's time zone.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.maintenance_start_time.describe(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.maintenance_start_time.describe gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_maintenance_start_time",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def update(
    hub,
    ctx,
    gateway_arn: str,
    hour_of_day: int,
    minute_of_hour: int,
    day_of_week: int = None,
    day_of_month: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a gateway's weekly maintenance start time information, including day and time of the week. The maintenance time is the time in your gateway's time zone.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        hour_of_day(int): The hour component of the maintenance start time represented as hh, where hh is the hour (00 to 23). The hour of the day is in the time zone of the gateway.
        minute_of_hour(int): The minute component of the maintenance start time represented as mm, where mm is the minute (00 to 59). The minute of the hour is in the time zone of the gateway.
        day_of_week(int, optional): The day of the week component of the maintenance start time week represented as an ordinal number from 0 to 6, where 0 represents Sunday and 6 Saturday. Defaults to None.
        day_of_month(int, optional): The day of the month component of the maintenance start time represented as an ordinal number from 1 to 28, where 1 represents the first day of the month and 28 represents the last day of the month. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.maintenance_start_time.update(
                ctx, gateway_arn=value, hour_of_day=value, minute_of_hour=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.maintenance_start_time.update gateway_arn=value, hour_of_day=value, minute_of_hour=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_maintenance_start_time",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "HourOfDay": hour_of_day,
            "MinuteOfHour": minute_of_hour,
            "DayOfWeek": day_of_week,
            "DayOfMonth": day_of_month,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub,
    ctx,
    id_: str,
    transmit_mode: int,
    payload_data: str,
    wireless_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends a decrypted application data frame to a device.

    Args:
        id_(str): The ID of the wireless device to receive the data.
        transmit_mode(int): The transmit mode to use to send data to the wireless device. Can be: 0 for UM (unacknowledge mode) or 1 for AM (acknowledge mode).
        payload_data(str): The binary to be sent to the end device, encoded in base64.
        wireless_metadata(Dict, optional): Metadata about the message request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.data_to_wireless_device.send(
                ctx, id_=value, transmit_mode=value, payload_data=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.data_to_wireless_device.send id_=value, transmit_mode=value, payload_data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="send_data_to_wireless_device",
        op_kwargs={
            "Id": id_,
            "TransmitMode": transmit_mode,
            "PayloadData": payload_data,
            "WirelessMetadata": wireless_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_cluster_identifier: str,
    engine: str,
    availability_zones: List = None,
    backup_retention_period: int = None,
    db_cluster_parameter_group_name: str = None,
    vpc_security_group_ids: List = None,
    db_subnet_group_name: str = None,
    engine_version: str = None,
    port: int = None,
    master_username: str = None,
    master_user_password: str = None,
    preferred_backup_window: str = None,
    preferred_maintenance_window: str = None,
    tags: List = None,
    storage_encrypted: bool = None,
    kms_key_id: str = None,
    pre_signed_url: str = None,
    enable_cloudwatch_logs_exports: List = None,
    deletion_protection: bool = None,
    global_cluster_identifier: str = None,
    source_region: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon DocumentDB cluster.

    Args:
        availability_zones(List, optional): A list of Amazon EC2 Availability Zones that instances in the cluster can be created in. Defaults to None.
        backup_retention_period(int, optional): The number of days for which automated backups are retained. You must specify a minimum value of 1. Default: 1 Constraints:   Must be a value from 1 to 35.  . Defaults to None.
        db_cluster_identifier(str): The cluster identifier. This parameter is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.    The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.    Example: my-cluster .
        db_cluster_parameter_group_name(str, optional): The name of the cluster parameter group to associate with this cluster. Defaults to None.
        vpc_security_group_ids(List, optional): A list of EC2 VPC security groups to associate with this cluster. . Defaults to None.
        db_subnet_group_name(str, optional): A subnet group to associate with this cluster. Constraints: Must match the name of an existing DBSubnetGroup. Must not be default. Example: mySubnetgroup . Defaults to None.
        engine(str): The name of the database engine to be used for this cluster. Valid values: docdb .
        engine_version(str, optional): The version number of the database engine to use. The --engine-version will default to the latest major engine version. For production workloads, we recommend explicitly declaring this parameter with the intended major engine version. Defaults to None.
        port(int, optional): The port number on which the instances in the cluster accept connections. Defaults to None.
        master_username(str, optional): The name of the master user for the cluster. Constraints:   Must be from 1 to 63 letters or numbers.   The first character must be a letter.   Cannot be a reserved word for the chosen database engine.   . Defaults to None.
        master_user_password(str, optional): The password for the master database user. This password can contain any printable ASCII character except forward slash (/), double quote ("), or the "at" symbol (@). Constraints: Must contain from 8 to 100 characters. Defaults to None.
        preferred_backup_window(str, optional): The daily time range during which automated backups are created if automated backups are enabled using the BackupRetentionPeriod parameter.  The default is a 30-minute window selected at random from an 8-hour block of time for each Region.  Constraints:   Must be in the format hh24:mi-hh24:mi.   Must be in Universal Coordinated Time (UTC).   Must not conflict with the preferred maintenance window.    Must be at least 30 minutes.  . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC). Format: ddd:hh24:mi-ddd:hh24:mi  The default is a 30-minute window selected at random from an 8-hour block of time for each Region, occurring on a random day of the week. Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun Constraints: Minimum 30-minute window. Defaults to None.
        tags(List, optional): The tags to be assigned to the cluster. Defaults to None.
        storage_encrypted(bool, optional): Specifies whether the cluster is encrypted. Defaults to None.
        kms_key_id(str, optional): The KMS key identifier for an encrypted cluster. The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are creating a cluster using the same account that owns the KMS encryption key that is used to encrypt the new cluster, you can use the KMS key alias instead of the ARN for the KMS encryption key. If an encryption key is not specified in KmsKeyId:    If the StorageEncrypted parameter is true, Amazon DocumentDB uses your default encryption key.    KMS creates the default encryption key for your account. Your account has a different default encryption key for each Regions. Defaults to None.
        pre_signed_url(str, optional): Not currently supported. . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): A list of log types that need to be enabled for exporting to Amazon CloudWatch Logs. You can enable audit logs or profiler logs. For more information, see  Auditing Amazon DocumentDB Events and  Profiling Amazon DocumentDB Operations. . Defaults to None.
        deletion_protection(bool, optional): Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted. Defaults to None.
        global_cluster_identifier(str, optional): The cluster identifier of the new global cluster. Defaults to None.
        source_region(str, optional): The ID of the region that contains the source for the db cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.init.create(
                ctx, db_cluster_identifier=value, engine=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.init.create db_cluster_identifier=value, engine=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="create_db_cluster",
        op_kwargs={
            "AvailabilityZones": availability_zones,
            "BackupRetentionPeriod": backup_retention_period,
            "DBClusterIdentifier": db_cluster_identifier,
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "DBSubnetGroupName": db_subnet_group_name,
            "Engine": engine,
            "EngineVersion": engine_version,
            "Port": port,
            "MasterUsername": master_username,
            "MasterUserPassword": master_user_password,
            "PreferredBackupWindow": preferred_backup_window,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "Tags": tags,
            "StorageEncrypted": storage_encrypted,
            "KmsKeyId": kms_key_id,
            "PreSignedUrl": pre_signed_url,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "DeletionProtection": deletion_protection,
            "GlobalClusterIdentifier": global_cluster_identifier,
            "SourceRegion": source_region,
        },
    )


async def delete(
    hub,
    ctx,
    db_cluster_identifier: str,
    skip_final_snapshot: bool = None,
    final_db_snapshot_identifier: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a previously provisioned cluster. When you delete a cluster, all automated backups for that cluster are deleted and can't be recovered. Manual DB cluster snapshots of the specified cluster are not deleted.

    Args:
        db_cluster_identifier(str): The cluster identifier for the cluster to be deleted. This parameter isn't case sensitive. Constraints:   Must match an existing DBClusterIdentifier.  .
        skip_final_snapshot(bool, optional):  Determines whether a final cluster snapshot is created before the cluster is deleted. If true is specified, no cluster snapshot is created. If false is specified, a cluster snapshot is created before the DB cluster is deleted.   If SkipFinalSnapshot is false, you must specify a FinalDBSnapshotIdentifier parameter.  Default: false . Defaults to None.
        final_db_snapshot_identifier(str, optional):  The cluster snapshot identifier of the new cluster snapshot created when SkipFinalSnapshot is set to false.    Specifying this parameter and also setting the SkipFinalShapshot parameter to true results in an error.   Constraints:   Must be from 1 to 255 letters, numbers, or hyphens.   The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.init.delete(ctx, db_cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.init.delete db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="delete_db_cluster",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "SkipFinalSnapshot": skip_final_snapshot,
            "FinalDBSnapshotIdentifier": final_db_snapshot_identifier,
        },
    )


async def describe_all(
    hub,
    ctx,
    db_cluster_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about provisioned Amazon DocumentDB clusters. This API operation supports pagination. For certain management features such as cluster and instance lifecycle management, Amazon DocumentDB leverages operational technology that is shared with Amazon RDS and Amazon Neptune. Use the filterName=engine,Values=docdb filter parameter to return only Amazon DocumentDB clusters.

    Args:
        db_cluster_identifier(str, optional): The user-provided cluster identifier. If this parameter is specified, information from only the specific cluster is returned. This parameter isn't case sensitive. Constraints:   If provided, must match an existing DBClusterIdentifier.  . Defaults to None.
        filters(List, optional): A filter that specifies one or more clusters to describe. Supported filters:    db-cluster-id - Accepts cluster identifiers and cluster Amazon Resource Names (ARNs). The results list only includes information about the clusters identified by these ARNs.  . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_db_clusters",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def failover(
    hub,
    ctx,
    db_cluster_identifier: str = None,
    target_db_instance_identifier: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Forces a failover for a cluster. A failover for a cluster promotes one of the Amazon DocumentDB replicas (read-only instances) in the cluster to be the primary instance (the cluster writer). If the primary instance fails, Amazon DocumentDB automatically fails over to an Amazon DocumentDB replica, if one exists. You can force a failover when you want to simulate a failure of a primary instance for testing.

    Args:
        db_cluster_identifier(str, optional): A cluster identifier to force a failover for. This parameter is not case sensitive. Constraints:   Must match the identifier of an existing DBCluster.  . Defaults to None.
        target_db_instance_identifier(str, optional): The name of the instance to promote to the primary instance. You must specify the instance identifier for an Amazon DocumentDB replica in the cluster. For example, mydbcluster-replica1. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.init.failover(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.init.failover
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="failover_db_cluster",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "TargetDBInstanceIdentifier": target_db_instance_identifier,
        },
    )


async def modify(
    hub,
    ctx,
    db_cluster_identifier: str,
    new_db_cluster_identifier: str = None,
    apply_immediately: bool = None,
    backup_retention_period: int = None,
    db_cluster_parameter_group_name: str = None,
    vpc_security_group_ids: List = None,
    port: int = None,
    master_user_password: str = None,
    preferred_backup_window: str = None,
    preferred_maintenance_window: str = None,
    cloudwatch_logs_export_configuration: Dict = None,
    engine_version: str = None,
    deletion_protection: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a setting for an Amazon DocumentDB cluster. You can change one or more database configuration parameters by specifying these parameters and the new values in the request.

    Args:
        db_cluster_identifier(str): The cluster identifier for the cluster that is being modified. This parameter is not case sensitive. Constraints:   Must match the identifier of an existing DBCluster.  .
        new_db_cluster_identifier(str, optional): The new cluster identifier for the cluster when renaming a cluster. This value is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: my-cluster2 . Defaults to None.
        apply_immediately(bool, optional): A value that specifies whether the changes in this request and any pending changes are asynchronously applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the cluster. If this parameter is set to false, changes to the cluster are applied during the next maintenance window. The ApplyImmediately parameter affects only the NewDBClusterIdentifier and MasterUserPassword values. If you set this parameter value to false, the changes to the NewDBClusterIdentifier and MasterUserPassword values are applied during the next maintenance window. All other changes are applied immediately, regardless of the value of the ApplyImmediately parameter. Default: false . Defaults to None.
        backup_retention_period(int, optional): The number of days for which automated backups are retained. You must specify a minimum value of 1. Default: 1 Constraints:   Must be a value from 1 to 35.  . Defaults to None.
        db_cluster_parameter_group_name(str, optional): The name of the cluster parameter group to use for the cluster. Defaults to None.
        vpc_security_group_ids(List, optional): A list of virtual private cloud (VPC) security groups that the cluster will belong to. Defaults to None.
        port(int, optional): The port number on which the cluster accepts connections. Constraints: Must be a value from 1150 to 65535.  Default: The same port as the original cluster. Defaults to None.
        master_user_password(str, optional): The password for the master database user. This password can contain any printable ASCII character except forward slash (/), double quote ("), or the "at" symbol (@). Constraints: Must contain from 8 to 100 characters. Defaults to None.
        preferred_backup_window(str, optional): The daily time range during which automated backups are created if automated backups are enabled, using the BackupRetentionPeriod parameter.  The default is a 30-minute window selected at random from an 8-hour block of time for each Region.  Constraints:   Must be in the format hh24:mi-hh24:mi.   Must be in Universal Coordinated Time (UTC).   Must not conflict with the preferred maintenance window.   Must be at least 30 minutes.  . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC). Format: ddd:hh24:mi-ddd:hh24:mi  The default is a 30-minute window selected at random from an 8-hour block of time for each Region, occurring on a random day of the week.  Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun Constraints: Minimum 30-minute window. Defaults to None.
        cloudwatch_logs_export_configuration(Dict, optional): The configuration setting for the log types to be enabled for export to Amazon CloudWatch Logs for a specific instance or cluster. The EnableLogTypes and DisableLogTypes arrays determine which logs are exported (or not exported) to CloudWatch Logs. Defaults to None.
        engine_version(str, optional): The version number of the database engine to which you want to upgrade. Modifying engine version is not supported on Amazon DocumentDB. Defaults to None.
        deletion_protection(bool, optional): Specifies whether this cluster can be deleted. If DeletionProtection is enabled, the cluster cannot be deleted unless it is modified and DeletionProtection is disabled. DeletionProtection protects clusters from being accidentally deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.init.modify(ctx, db_cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.init.modify db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="modify_db_cluster",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "NewDBClusterIdentifier": new_db_cluster_identifier,
            "ApplyImmediately": apply_immediately,
            "BackupRetentionPeriod": backup_retention_period,
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "Port": port,
            "MasterUserPassword": master_user_password,
            "PreferredBackupWindow": preferred_backup_window,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "CloudwatchLogsExportConfiguration": cloudwatch_logs_export_configuration,
            "EngineVersion": engine_version,
            "DeletionProtection": deletion_protection,
        },
    )


async def start(hub, ctx, db_cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Restarts the stopped cluster that is specified by DBClusterIdentifier. For more information, see Stopping and Starting an Amazon DocumentDB Cluster.

    Args:
        db_cluster_identifier(str): The identifier of the cluster to restart. Example: docdb-2019-05-28-15-24-52 .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.init.start(ctx, db_cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.init.start db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="start_db_cluster",
        op_kwargs={"DBClusterIdentifier": db_cluster_identifier},
    )


async def stop(hub, ctx, db_cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the running cluster that is specified by DBClusterIdentifier. The cluster must be in the available state. For more information, see Stopping and Starting an Amazon DocumentDB Cluster.

    Args:
        db_cluster_identifier(str): The identifier of the cluster to stop. Example: docdb-2019-05-28-15-24-52 .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.cluster.init.stop(ctx, db_cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.cluster.init.stop db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="stop_db_cluster",
        op_kwargs={"DBClusterIdentifier": db_cluster_identifier},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def infer(hub, ctx, text: str) -> Dict:
    r"""
    **Autogenerated function**

    InferRxNorm detects medications as entities listed in a patient record and links to the normalized concept identifiers in the RxNorm database from the National Library of Medicine. Amazon Comprehend Medical only detects medical entities in English language texts.

    Args:
        text(str): The input text used for analysis. The input for InferRxNorm is a string from 1 to 10000 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.rx_norm.init.infer(ctx, text=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.rx_norm.init.infer text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="infer_rx_norm",
        op_kwargs={"Text": text},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the requested policy generation.

    Args:
        job_id(str): The JobId that is returned by the StartPolicyGeneration operation. The JobId can be used with GetGeneratedPolicy to retrieve the generated policies or used with CancelPolicyGeneration to cancel the policy generation request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.policy.generation.cancel(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.policy.generation.cancel job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="cancel_policy_generation",
        op_kwargs={"jobId": job_id},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, principal_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the policy generations requested in the last seven days.

    Args:
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned. Defaults to None.
        principal_arn(str, optional): The ARN of the IAM entity (user or role) for which you are generating a policy. Use this with ListGeneratedPolicies to filter the results to only include results for a specific principal. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.policy.generation.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.policy.generation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="list_policy_generations",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "principalArn": principal_arn,
        },
    )


async def start(
    hub,
    ctx,
    policy_generation_details: Dict,
    client_token: str = None,
    cloud_trail_details: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the policy generation request.

    Args:
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you do not specify a client token, one is automatically generated by the AWS SDK. Defaults to None.
        cloud_trail_details(Dict, optional): A CloudTrailDetails object that contains details about a Trail that you want to analyze to generate policies. Defaults to None.
        policy_generation_details(Dict): Contains the ARN of the IAM entity (user or role) for which you are generating a policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.policy.generation.start(
                ctx, policy_generation_details=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.policy.generation.start policy_generation_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="start_policy_generation",
        op_kwargs={
            "clientToken": client_token,
            "cloudTrailDetails": cloud_trail_details,
            "policyGenerationDetails": policy_generation_details,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, uri: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the integrations associated to a specific URI in the AWS account.

    Args:
        uri(str): The URI of the S3 bucket or any other type of data source.
        next_token(str, optional): The pagination token from the previous ListAccountIntegrations API call. Defaults to None.
        max_results(int, optional): The maximum number of objects returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.account_integration.list_all(ctx, uri=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.account_integration.list_all uri=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="list_account_integrations",
        op_kwargs={"Uri": uri, "NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    aws_account_id: str,
    entry_point: str = None,
    session_lifetime_in_minutes: int = None,
    user_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a session URL and authorization code that you can use to embed the Amazon QuickSight console in your web server code. Use GetSessionEmbedUrl where you want to provide an authoring portal that allows users to create data sources, datasets, analyses, and dashboards. The users who access an embedded QuickSight console need belong to the author or admin security cohort. If you want to restrict permissions to some of these features, add a custom permissions profile to the user with the  UpdateUser  API operation. Use  RegisterUser  API operation to add a new user with a custom permission profile attached. For more information, see the following sections in the Amazon QuickSight User Guide:    Embedding the Amazon QuickSight Console     Customizing Access to the Amazon QuickSight Console

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; associated with your QuickSight subscription.
        entry_point(str, optional): The URL you use to access the embedded session. The entry point URL is constrained to the following paths:    /start     /start/analyses     /start/dashboards     /start/favorites     /dashboards/DashboardId  - where DashboardId is the actual ID key from the QuickSight console URL of the dashboard    /analyses/AnalysisId  - where AnalysisId is the actual ID key from the QuickSight console URL of the analysis  . Defaults to None.
        session_lifetime_in_minutes(int, optional): How many minutes the session is valid. The session lifetime must be 15-600 minutes. Defaults to None.
        user_arn(str, optional): The Amazon QuickSight user's Amazon Resource Name (ARN), for use with QUICKSIGHT identity type. You can use this for any type of Amazon QuickSight users in your account (readers, authors, or admins). They need to be authenticated as one of the following:   Active Directory (AD) users or group members   Invited nonfederated users   Identity and Access Management (IAM) users and IAM role-based sessions authenticated through Federated Single Sign-On using SAML, OpenID Connect, or IAM federation   Omit this parameter for users in the third group, IAM users and IAM role-based sessions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.session_embed_url.get(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.session_embed_url.get aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="get_session_embed_url",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "EntryPoint": entry_point,
            "SessionLifetimeInMinutes": session_lifetime_in_minutes,
            "UserArn": user_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(hub, ctx, document: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Detects text in the input document. Amazon Textract can detect lines of text and the words that make up a line of text. The input document must be an image in JPEG or PNG format. DetectDocumentText returns the detected text in an array of Block objects.  Each document page has as an associated Block of type PAGE. Each PAGE Block object is the parent of LINE Block objects that represent the lines of detected text on a page. A LINE Block object is a parent for each word that makes up the line. Words are represented by Block objects of type WORD.  DetectDocumentText is a synchronous operation. To analyze documents asynchronously, use StartDocumentTextDetection. For more information, see Document Text Detection.

    Args:
        document(Dict): The input document as base64-encoded bytes or an Amazon S3 object. If you use the AWS CLI to call Amazon Textract operations, you can't pass image bytes. The document must be an image in JPEG or PNG format. If you're using an AWS SDK to call Amazon Textract, you might not need to base64-encode image bytes that are passed using the Bytes field. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.textract.document.text.init.detect(ctx, document=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.textract.document.text.init.detect document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="textract",
        operation="detect_document_text",
        op_kwargs={"Document": document},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def search(
    hub,
    ctx,
    index_name: str,
    text: str,
    bias_position: List = None,
    filter_b_box: List = None,
    filter_countries: List = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Geocodes free-form text, such as an address, name, city, or region to allow you to search for Places or points of interest.  Includes the option to apply additional parameters to narrow your list of results.  You can search for places near a given position using BiasPosition, or filter results within a bounding box using FilterBBox. Providing both parameters simultaneously returns an error.

    Args:
        bias_position(List, optional): Searches for results closest to the given position. An optional parameter defined by longitude, and latitude.   The first bias position is the X coordinate, or longitude.   The second bias position is the Y coordinate, or latitude.    For example, bias=xLongitude&bias=yLatitude. Defaults to None.
        filter_b_box(List, optional): Filters the results by returning only Places within the provided bounding box. An optional parameter. The first 2 bbox parameters describe the lower southwest corner:   The first bbox position is the X coordinate or longitude of the lower southwest corner.   The second bbox position is the Y coordinate or latitude of the lower southwest corner.   For example, bbox=xLongitudeSW&bbox=yLatitudeSW. The next bbox parameters describe the upper northeast corner:   The third bbox position is the X coordinate, or longitude of the upper northeast corner.   The fourth bbox position is the Y coordinate, or longitude of the upper northeast corner.   For example, bbox=xLongitudeNE&bbox=yLatitudeNE . Defaults to None.
        filter_countries(List, optional): Limits the search to the given a list of countries/regions. An optional parameter.   Use the ISO 3166 3-digit country code. For example, Australia uses three upper-case characters: AUS.  . Defaults to None.
        index_name(str): The name of the place index resource you want to use for the search.
        max_results(int, optional): An optional parameter. The maximum number of results returned per request.  The default: 50 . Defaults to None.
        text(str): The address, name, city, or region to be used in the search. In free-form text format. For example, 123 Any Street.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.place_index.for_.text.search(
                ctx, index_name=value, text=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.place_index.for_.text.search index_name=value, text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="search_place_index_for_text",
        op_kwargs={
            "BiasPosition": bias_position,
            "FilterBBox": filter_b_box,
            "FilterCountries": filter_countries,
            "IndexName": index_name,
            "MaxResults": max_results,
            "Text": text,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    connection_notification_arn: str,
    connection_events: List,
    dry_run: bool = None,
    service_id: str = None,
    vpc_endpoint_id: str = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a connection notification for a specified VPC endpoint or VPC endpoint service. A connection notification notifies you of specific endpoint events. You must create an SNS topic to receive notifications. For more information, see Create a Topic in the Amazon Simple Notification Service Developer Guide. You can create a connection notification for interface endpoints only.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        service_id(str, optional): The ID of the endpoint service. Defaults to None.
        vpc_endpoint_id(str, optional): The ID of the endpoint. Defaults to None.
        connection_notification_arn(str): The ARN of the SNS topic for the notifications.
        connection_events(List): One or more endpoint events for which to receive notifications. Valid values are Accept, Connect, Delete, and Reject.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.connection.notification.create(
                ctx, connection_notification_arn=value, connection_events=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.connection.notification.create connection_notification_arn=value, connection_events=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_vpc_endpoint_connection_notification",
        op_kwargs={
            "DryRun": dry_run,
            "ServiceId": service_id,
            "VpcEndpointId": vpc_endpoint_id,
            "ConnectionNotificationArn": connection_notification_arn,
            "ConnectionEvents": connection_events,
            "ClientToken": client_token,
        },
    )


async def delete_multiple(
    hub, ctx, connection_notification_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more VPC endpoint connection notifications.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        connection_notification_ids(List): One or more notification IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.connection.notification.delete_multiple(
                ctx, connection_notification_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.connection.notification.delete_multiple connection_notification_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_vpc_endpoint_connection_notifications",
        op_kwargs={
            "DryRun": dry_run,
            "ConnectionNotificationIds": connection_notification_ids,
        },
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    connection_notification_id: str = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the connection notifications for VPC endpoints and VPC endpoint services.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        connection_notification_id(str, optional): The ID of the notification. Defaults to None.
        filters(List, optional): One or more filters.    connection-notification-arn - The ARN of the SNS topic for the notification.    connection-notification-id - The ID of the notification.    connection-notification-state - The state of the notification (Enabled | Disabled).    connection-notification-type - The type of notification (Topic).    service-id - The ID of the endpoint service.    vpc-endpoint-id - The ID of the VPC endpoint.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.connection.notification.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.connection.notification.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_endpoint_connection_notifications",
        op_kwargs={
            "DryRun": dry_run,
            "ConnectionNotificationId": connection_notification_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    connection_notification_id: str,
    dry_run: bool = None,
    connection_notification_arn: str = None,
    connection_events: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a connection notification for VPC endpoint or VPC endpoint service. You can change the SNS topic for the notification, or the events for which to be notified.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        connection_notification_id(str): The ID of the notification.
        connection_notification_arn(str, optional): The ARN for the SNS topic for the notification. Defaults to None.
        connection_events(List, optional): One or more events for the endpoint. Valid values are Accept, Connect, Delete, and Reject. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.endpoint.connection.notification.modify(
                ctx, connection_notification_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.endpoint.connection.notification.modify connection_notification_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpc_endpoint_connection_notification",
        op_kwargs={
            "DryRun": dry_run,
            "ConnectionNotificationId": connection_notification_id,
            "ConnectionNotificationArn": connection_notification_arn,
            "ConnectionEvents": connection_events,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, satellite_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of ground stations.

    Args:
        max_results(int, optional): Maximum number of ground stations returned. Defaults to None.
        next_token(str, optional): Next token that can be supplied in the next call to get the next page of ground stations. Defaults to None.
        satellite_id(str, optional): Satellite ID to retrieve on-boarded ground stations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.ground_station.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.ground_station.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="list_ground_stations",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "satelliteId": satellite_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, account_id: str, budget_name: str, notification: Dict, subscribers: List
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a notification. You must create the budget before you create the associated notification.

    Args:
        account_id(str): The accountId that is associated with the budget that you want to create a notification for.
        budget_name(str): The name of the budget that you want AWS to notify you about. Budget names must be unique within an account.
        notification(Dict): The notification that you want to create.
        subscribers(List): A list of subscribers that you want to associate with the notification. Each notification can have one SNS subscriber and up to 10 email subscribers.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.notification.init.create(
                ctx, account_id=value, budget_name=value, notification=value, subscribers=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.notification.init.create account_id=value, budget_name=value, notification=value, subscribers=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="create_notification",
        op_kwargs={
            "AccountId": account_id,
            "BudgetName": budget_name,
            "Notification": notification,
            "Subscribers": subscribers,
        },
    )


async def delete(
    hub, ctx, account_id: str, budget_name: str, notification: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a notification.  Deleting a notification also deletes the subscribers that are associated with the notification.

    Args:
        account_id(str): The accountId that is associated with the budget whose notification you want to delete.
        budget_name(str): The name of the budget whose notification you want to delete.
        notification(Dict): The notification that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.notification.init.delete(
                ctx, account_id=value, budget_name=value, notification=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.notification.init.delete account_id=value, budget_name=value, notification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="delete_notification",
        op_kwargs={
            "AccountId": account_id,
            "BudgetName": budget_name,
            "Notification": notification,
        },
    )


async def update(
    hub,
    ctx,
    account_id: str,
    budget_name: str,
    old_notification: Dict,
    new_notification: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a notification.

    Args:
        account_id(str): The accountId that is associated with the budget whose notification you want to update.
        budget_name(str): The name of the budget whose notification you want to update.
        old_notification(Dict): The previous notification that is associated with a budget.
        new_notification(Dict): The updated notification to be associated with a budget.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.notification.init.update(
                ctx,
                account_id=value,
                budget_name=value,
                old_notification=value,
                new_notification=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.notification.init.update account_id=value, budget_name=value, old_notification=value, new_notification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="update_notification",
        op_kwargs={
            "AccountId": account_id,
            "BudgetName": budget_name,
            "OldNotification": old_notification,
            "NewNotification": new_notification,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, user_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the header information for the .csv file to be used as input for the user import job.

    Args:
        user_pool_id(str): The user pool ID for the user pool that the users are to be imported into.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.csv_header.get(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.csv_header.get user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="get_csv_header",
        op_kwargs={"UserPoolId": user_pool_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    function_name: str,
    role: str,
    code: Dict,
    runtime: str = None,
    handler: str = None,
    description: str = None,
    timeout: int = None,
    memory_size: int = None,
    publish: bool = None,
    vpc_config: Dict = None,
    package_type: str = None,
    dead_letter_config: Dict = None,
    environment: Dict = None,
    kms_key_arn: str = None,
    tracing_config: Dict = None,
    tags: Dict = None,
    layers: List = None,
    file_system_configs: List = None,
    image_config: Dict = None,
    code_signing_config_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Lambda function. To create a function, you need a deployment package and an execution role. The deployment package is a .zip file archive or container image that contains your function code. The execution role grants the function permission to use Amazon Web Services services, such as Amazon CloudWatch Logs for log streaming and X-Ray for request tracing. You set the package type to Image if the deployment package is a container image. For a container image, the code property must include the URI of a container image in the Amazon ECR registry. You do not need to specify the handler and runtime properties.  You set the package type to Zip if the deployment package is a .zip file archive. For a .zip file archive, the code property specifies the location of the .zip file. You must also specify the handler and runtime properties. When you create a function, Lambda provisions an instance of the function and its supporting resources. If your function connects to a VPC, this process can take a minute or so. During this time, you can't invoke or modify the function. The State, StateReason, and StateReasonCode fields in the response from GetFunctionConfiguration indicate when the function is ready to invoke. For more information, see Function States. A function has an unpublished version, and can have published versions and aliases. The unpublished version changes when you update your function's code and configuration. A published version is a snapshot of your function code and configuration that can't be changed. An alias is a named resource that maps to a version, and can be changed to map to a different version. Use the Publish parameter to create version 1 of your function from its initial configuration. The other parameters let you configure version-specific and function-level settings. You can modify version-specific settings later with UpdateFunctionConfiguration. Function-level settings apply to both the unpublished and published versions of the function, and include tags (TagResource) and per-function concurrency limits (PutFunctionConcurrency). You can use code signing if your deployment package is a .zip file archive. To enable code signing for this function, specify the ARN of a code-signing configuration. When a user attempts to deploy a code package with UpdateFunctionCode, Lambda checks that the code package has a valid signature from a trusted publisher. The code-signing configuration includes set set of signing profiles, which define the trusted publishers for this function. If another account or an Amazon Web Services service invokes your function, use AddPermission to grant permission by creating a resource-based IAM policy. You can grant permissions at the function level, on a version, or on an alias. To invoke your function directly, use Invoke. To invoke your function in response to events in other Amazon Web Services services, create an event source mapping (CreateEventSourceMapping), or configure a function trigger in the other service. For more information, see Invoking Functions.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        runtime(str, optional): The identifier of the function's runtime. Defaults to None.
        role(str): The Amazon Resource Name (ARN) of the function's execution role.
        handler(str, optional): The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see Programming Model. Defaults to None.
        code(Dict): The code for the function.
        description(str, optional): A description of the function. Defaults to None.
        timeout(int, optional): The amount of time that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For additional information, see Lambda execution environment. Defaults to None.
        memory_size(int, optional): The amount of memory available to the function at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB. Defaults to None.
        publish(bool, optional): Set to true to publish the first version of the function during creation. Defaults to None.
        vpc_config(Dict, optional): For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can only access resources and the internet through that VPC. For more information, see VPC Settings. Defaults to None.
        package_type(str, optional): The type of deployment package. Set to Image for container image and set Zip for ZIP archive. Defaults to None.
        dead_letter_config(Dict, optional): A dead letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see Dead Letter Queues. Defaults to None.
        environment(Dict, optional): Environment variables that are accessible from function code during execution. Defaults to None.
        kms_key_arn(str, optional): The ARN of the Amazon Web Services Key Management Service (KMS) key that's used to encrypt your function's environment variables. If it's not provided, Lambda uses a default service key. Defaults to None.
        tracing_config(Dict, optional): Set Mode to Active to sample and trace a subset of incoming requests with X-Ray. Defaults to None.
        tags(Dict, optional): A list of tags to apply to the function. Defaults to None.
        layers(List, optional): A list of function layers to add to the function's execution environment. Specify each layer by its ARN, including the version. Defaults to None.
        file_system_configs(List, optional): Connection settings for an Amazon EFS file system. Defaults to None.
        image_config(Dict, optional): Container image configuration values that override the values in the container image Dockerfile. Defaults to None.
        code_signing_config_arn(str, optional): To enable code signing for this function, specify the ARN of a code-signing configuration. A code-signing configuration includes a set of signing profiles, which define the trusted publishers for this function. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.init.create(
                ctx, function_name=value, role=value, code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.init.create function_name=value, role=value, code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="create_function",
        op_kwargs={
            "FunctionName": function_name,
            "Runtime": runtime,
            "Role": role,
            "Handler": handler,
            "Code": code,
            "Description": description,
            "Timeout": timeout,
            "MemorySize": memory_size,
            "Publish": publish,
            "VpcConfig": vpc_config,
            "PackageType": package_type,
            "DeadLetterConfig": dead_letter_config,
            "Environment": environment,
            "KMSKeyArn": kms_key_arn,
            "TracingConfig": tracing_config,
            "Tags": tags,
            "Layers": layers,
            "FileSystemConfigs": file_system_configs,
            "ImageConfig": image_config,
            "CodeSigningConfigArn": code_signing_config_arn,
        },
    )


async def delete(hub, ctx, function_name: str, qualifier: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes a Lambda function. To delete a specific function version, use the Qualifier parameter. Otherwise, all versions and aliases are deleted. To delete Lambda event source mappings that invoke a function, use DeleteEventSourceMapping. For Amazon Web Services services and resources that invoke your function directly, delete the trigger in the service where you originally configured it.

    Args:
        function_name(str): The name of the Lambda function or version.  Name formats     Function name - my-function (name-only), my-function:1 (with version).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): Specify a version to delete. You can't delete a version that's referenced by an alias. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.init.delete(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.init.delete function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_function",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )


async def get(hub, ctx, function_name: str, qualifier: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the function or function version, with a link to download the deployment package that's valid for 10 minutes. If you specify a function version, only details that are specific to that version are returned.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): Specify a version or alias to get details about a published version of the function. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.init.get(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.init.get function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_function",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )


async def list_all(
    hub,
    ctx,
    master_region: str = None,
    function_version: str = None,
    marker: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of Lambda functions, with the version-specific configuration of each. Lambda returns up to 50 functions per call. Set FunctionVersion to ALL to include all published versions of each function in addition to the unpublished version.   The ListFunctions action returns a subset of the FunctionConfiguration fields. To get the additional fields (State, StateReasonCode, StateReason, LastUpdateStatus, LastUpdateStatusReason, LastUpdateStatusReasonCode) for a function or version, use GetFunction.

    Args:
        master_region(str, optional): For Lambda@Edge functions, the Region of the master function. For example, us-east-1 filters the list of functions to only include Lambda@Edge functions replicated from a master function in US East (N. Virginia). If specified, you must set FunctionVersion to ALL. Defaults to None.
        function_version(str, optional): Set to ALL to include entries for all published versions of each function. Defaults to None.
        marker(str, optional): Specify the pagination token that's returned by a previous request to retrieve the next page of results. Defaults to None.
        max_items(int, optional): The maximum number of functions to return in the response. Note that ListFunctions returns a maximum of 50 items in each response, even if you set the number higher. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_functions",
        op_kwargs={
            "MasterRegion": master_region,
            "FunctionVersion": function_version,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def decrease(hub, ctx, stream_name: str, retention_period_hours: int) -> None:
    r"""
    **Autogenerated function**

    Decreases the Kinesis data stream's retention period, which is the length of time data records are accessible after they are added to the stream. The minimum value of a stream's retention period is 24 hours. This operation may result in lost data. For example, if the stream's retention period is 48 hours and is decreased to 24 hours, any data already in the stream that is older than 24 hours is inaccessible.

    Args:
        stream_name(str): The name of the stream to modify.
        retention_period_hours(int): The new retention period of the stream, in hours. Must be less than the current retention period.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.retention_period.decrease(
                ctx, stream_name=value, retention_period_hours=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.retention_period.decrease stream_name=value, retention_period_hours=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="decrease_stream_retention_period",
        op_kwargs={
            "StreamName": stream_name,
            "RetentionPeriodHours": retention_period_hours,
        },
    )


async def increase(hub, ctx, stream_name: str, retention_period_hours: int) -> None:
    r"""
    **Autogenerated function**

    Increases the Kinesis data stream's retention period, which is the length of time data records are accessible after they are added to the stream. The maximum value of a stream's retention period is 168 hours (7 days). If you choose a longer stream retention period, this operation increases the time period during which records that have not yet expired are accessible. However, it does not make previous, expired data (older than the stream's previous retention period) accessible after the operation has been called. For example, if a stream's retention period is set to 24 hours and is increased to 168 hours, any data that is older than 24 hours remains inaccessible to consumer applications.

    Args:
        stream_name(str): The name of the stream to modify.
        retention_period_hours(int): The new retention period of the stream, in hours. Must be more than the current retention period.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.stream.retention_period.increase(
                ctx, stream_name=value, retention_period_hours=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.stream.retention_period.increase stream_name=value, retention_period_hours=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="increase_stream_retention_period",
        op_kwargs={
            "StreamName": stream_name,
            "RetentionPeriodHours": retention_period_hours,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, identity_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the status of the last BulkPublish operation for an identity pool.This API can only be called with developer credentials. You cannot call this API with the temporary user credentials provided by Cognito Identity.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.bulk_publish_detail.get_all(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.bulk_publish_detail.get_all identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="get_bulk_publish_details",
        op_kwargs={"IdentityPoolId": identity_pool_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, text_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Determines the dominant language of the input text for a batch of documents. For a list of languages that Amazon Comprehend can detect, see Amazon Comprehend Supported Languages.

    Args:
        text_list(List): A list containing the text of the input documents. The list can contain a maximum of 25 documents. Each document should contain at least 20 characters and must contain fewer than 5,000 bytes of UTF-8 encoded characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.detect.dominant_language.batch(ctx, text_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.detect.dominant_language.batch text_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="batch_detect_dominant_language",
        op_kwargs={"TextList": text_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(hub, ctx, text: str) -> Dict:
    r"""
    **Autogenerated function**

    The DetectEntities operation is deprecated. You should use the DetectEntitiesV2 operation instead.  Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information .

    Args:
        text(str):  A UTF-8 text string containing the clinical content being examined for entities. Each string must contain fewer than 20,000 bytes of characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehendmedical.entity.init.detect(ctx, text=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehendmedical.entity.init.detect text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehendmedical",
        operation="detect_entities",
        op_kwargs={"Text": text},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    bot_id: str,
    bot_version_locale_specification: Dict,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of the bot based on the DRAFT version. If the DRAFT version of this resource hasn't changed since you created the last version, Amazon Lex doesn't create a new version, it returns the last created version. When you create the first version of a bot, Amazon Lex sets the version to 1. Subsequent versions increment by 1.

    Args:
        bot_id(str): The identifier of the bot to create the version for.
        description(str, optional): A description of the version. Use the description to help identify the version in lists. Defaults to None.
        bot_version_locale_specification(Dict): Specifies the locales that Amazon Lex adds to this version. You can choose the Draft version or any other previously published version for each locale. When you specify a source version, the locale data is copied from the source version to the new version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.version.create(
                ctx, bot_id=value, bot_version_locale_specification=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.version.create bot_id=value, bot_version_locale_specification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_bot_version",
        op_kwargs={
            "botId": bot_id,
            "description": description,
            "botVersionLocaleSpecification": bot_version_locale_specification,
        },
    )


async def delete(
    hub, ctx, bot_id: str, bot_version: str, skip_resource_in_use_check: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specific version of a bot. To delete all version of a bot, use the DeleteBot operation.

    Args:
        bot_id(str): The identifier of the bot that contains the version.
        bot_version(str): The version of the bot to delete.
        skip_resource_in_use_check(bool, optional): By default, the DeleteBotVersion operations throws a ResourceInUseException exception if you try to delete a bot version that has an alias pointing at it. Set the skipResourceInUseCheck parameter to true to skip this check and remove the version even if an alias points to it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.version.delete(
                ctx, bot_id=value, bot_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.version.delete bot_id=value, bot_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_bot_version",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "skipResourceInUseCheck": skip_resource_in_use_check,
        },
    )


async def describe(hub, ctx, bot_id: str, bot_version: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides metadata about a version of a bot.

    Args:
        bot_id(str): The identifier of the bot containing the version to return metadata for.
        bot_version(str): The version of the bot to return metadata for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.version.describe(
                ctx, bot_id=value, bot_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.version.describe bot_id=value, bot_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_bot_version",
        op_kwargs={"botId": bot_id, "botVersion": bot_version},
    )


async def list_all(
    hub,
    ctx,
    bot_id: str,
    sort_by: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about all of the versions of a bot. The ListBotVersions operation returns a summary of each version of a bot. For example, if a bot has three numbered versions, the ListBotVersions operation returns for summaries, one for each numbered version and one for the DRAFT version. The ListBotVersions operation always returns at least one version, the DRAFT version.

    Args:
        bot_id(str): The identifier of the bot to list versions for.
        sort_by(Dict, optional): Specifies sorting parameters for the list of versions. You can specify that the list be sorted by version name in either ascending or descending order. Defaults to None.
        max_results(int, optional): The maximum number of versions to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response to the ListBotVersion operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.bot.version.list_all(ctx, bot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.bot.version.list_all bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_bot_versions",
        op_kwargs={
            "botId": bot_id,
            "sortBy": sort_by,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    environment_name: str = None,
    environment_id: str = None,
    attribute_names: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the overall health of the specified environment. The DescribeEnvironmentHealth operation is only available with AWS Elastic Beanstalk Enhanced Health.

    Args:
        environment_name(str, optional): Specify the environment by name. You must specify either this or an EnvironmentName, or both. Defaults to None.
        environment_id(str, optional): Specify the environment by ID. You must specify either this or an EnvironmentName, or both. Defaults to None.
        attribute_names(List, optional): Specify the response elements to return. To retrieve all attributes, set to All. If no attribute names are specified, returns the name of the environment. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.health.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.health.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_environment_health",
        op_kwargs={
            "EnvironmentName": environment_name,
            "EnvironmentId": environment_id,
            "AttributeNames": attribute_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    site_id: str,
    description: str = None,
    availability_zone: str = None,
    availability_zone_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Outpost. You can specify AvailabilityZone or AvailabilityZoneId.

    Args:
        name(str): The name of the Outpost.
        description(str, optional): The description of the Outpost. Defaults to None.
        site_id(str): The ID of the site.
        availability_zone(str, optional): The Availability Zone. Defaults to None.
        availability_zone_id(str, optional): The ID of the Availability Zone. Defaults to None.
        tags(Dict, optional): The tags to apply to the Outpost. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.outpost.outpost.init.create(ctx, name=value, site_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.outpost.outpost.init.create name=value, site_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="outposts",
        operation="create_outpost",
        op_kwargs={
            "Name": name,
            "Description": description,
            "SiteId": site_id,
            "AvailabilityZone": availability_zone,
            "AvailabilityZoneId": availability_zone_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, outpost_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the Outpost.

    Args:
        outpost_id(str): The ID of the Outpost.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.outpost.outpost.init.delete(ctx, outpost_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.outpost.outpost.init.delete outpost_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="outposts",
        operation="delete_outpost",
        op_kwargs={"OutpostId": outpost_id},
    )


async def get(hub, ctx, outpost_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified Outpost.

    Args:
        outpost_id(str): The ID of the Outpost.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.outpost.outpost.init.get(ctx, outpost_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.outpost.outpost.init.get outpost_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="outposts",
        operation="get_outpost",
        op_kwargs={"OutpostId": outpost_id},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    life_cycle_status_filter: List = None,
    availability_zone_filter: List = None,
    availability_zone_id_filter: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a list of the Outposts for your AWS account. Add filters to your request to return a more specific list of results. Use filters to match an Outpost lifecycle status, Availibility Zone (us-east-1a), and AZ ID (use1-az1).  If you specify multiple filters, the filters are joined with an AND, and the request returns only results that match all of the specified filters.

    Args:
        next_token(str, optional): The pagination token. Defaults to None.
        max_results(int, optional): The maximum page size. Defaults to None.
        life_cycle_status_filter(List, optional):  A filter for the lifecycle status of the Outpost.   Filter values are case sensitive. If you specify multiple values for a filter, the values are joined with an OR, and the request returns all results that match any of the specified values. . Defaults to None.
        availability_zone_filter(List, optional):  A filter for the Availibility Zone (us-east-1a) of the Outpost.   Filter values are case sensitive. If you specify multiple values for a filter, the values are joined with an OR, and the request returns all results that match any of the specified values. . Defaults to None.
        availability_zone_id_filter(List, optional):  A filter for the AZ IDs (use1-az1) of the Outpost.   Filter values are case sensitive. If you specify multiple values for a filter, the values are joined with an OR, and the request returns all results that match any of the specified values. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.outpost.outpost.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.outpost.outpost.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="outposts",
        operation="list_outposts",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "LifeCycleStatusFilter": life_cycle_status_filter,
            "AvailabilityZoneFilter": availability_zone_filter,
            "AvailabilityZoneIdFilter": availability_zone_id_filter,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def lookup(
    hub,
    ctx,
    identity_pool_id: str,
    identity_id: str = None,
    developer_user_identifier: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the IdentityID associated with a DeveloperUserIdentifier or the list of DeveloperUserIdentifier values associated with an IdentityId for an existing identity. Either IdentityID or DeveloperUserIdentifier must not be null. If you supply only one of these values, the other value will be searched in the database and returned as a part of the response. If you supply both, DeveloperUserIdentifier will be matched against IdentityID. If the values are verified against the database, the response returns both values and is the same as the request. Otherwise a ResourceConflictException is thrown.  LookupDeveloperIdentity is intended for low-throughput control plane operations: for example, to enable customer service to locate an identity ID by username. If you are using it for higher-volume operations such as user authentication, your requests are likely to be throttled. GetOpenIdTokenForDeveloperIdentity is a better option for higher-volume operations for user authentication. You must use AWS Developer credentials to call this API.

    Args:
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.
        identity_id(str, optional): A unique identifier in the format REGION:GUID. Defaults to None.
        developer_user_identifier(str, optional): A unique ID used by your backend authentication process to identify a user. Typically, a developer identity provider would issue many developer user identifiers, in keeping with the number of users. Defaults to None.
        max_results(int, optional): The maximum number of identities to return. Defaults to None.
        next_token(str, optional): A pagination token. The first call you make will have NextToken set to null. After that the service will return NextToken values as needed. For example, let's say you make a request with MaxResults set to 10, and there are 20 matches in the database. The service will return a pagination token as a part of the response. This token can be used to call the API again and get results starting from the 11th match. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.developer_identity.lookup(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.developer_identity.lookup identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="lookup_developer_identity",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "DeveloperUserIdentifier": developer_user_identifier,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def merge(
    hub,
    ctx,
    source_user_identifier: str,
    destination_user_identifier: str,
    developer_provider_name: str,
    identity_pool_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Merges two users having different IdentityIds, existing in the same identity pool, and identified by the same developer provider. You can use this action to request that discrete users be merged and identified as a single user in the Cognito environment. Cognito associates the given source user (SourceUserIdentifier) with the IdentityId of the DestinationUserIdentifier. Only developer-authenticated users can be merged. If the users to be merged are associated with the same public provider, but as two different users, an exception will be thrown. The number of linked logins is limited to 20. So, the number of linked logins for the source user, SourceUserIdentifier, and the destination user, DestinationUserIdentifier, together should not be larger than 20. Otherwise, an exception will be thrown. You must use AWS Developer credentials to call this API.

    Args:
        source_user_identifier(str): User identifier for the source user. The value should be a DeveloperUserIdentifier.
        destination_user_identifier(str): User identifier for the destination user. The value should be a DeveloperUserIdentifier.
        developer_provider_name(str): The "domain" by which Cognito will refer to your users. This is a (pseudo) domain name that you provide while creating an identity pool. This name acts as a placeholder that allows your backend and the Cognito service to communicate about the developer provider. For the DeveloperProviderName, you can use letters as well as period (.), underscore (_), and dash (-).
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.developer_identity.merge(
                ctx,
                source_user_identifier=value,
                destination_user_identifier=value,
                developer_provider_name=value,
                identity_pool_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.developer_identity.merge source_user_identifier=value, destination_user_identifier=value, developer_provider_name=value, identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="merge_developer_identities",
        op_kwargs={
            "SourceUserIdentifier": source_user_identifier,
            "DestinationUserIdentifier": destination_user_identifier,
            "DeveloperProviderName": developer_provider_name,
            "IdentityPoolId": identity_pool_id,
        },
    )


async def unlink(
    hub,
    ctx,
    identity_id: str,
    identity_pool_id: str,
    developer_provider_name: str,
    developer_user_identifier: str,
) -> None:
    r"""
    **Autogenerated function**

    Unlinks a DeveloperUserIdentifier from an existing identity. Unlinked developer users will be considered new identities next time they are seen. If, for a given Cognito identity, you remove all federated identities as well as the developer user identifier, the Cognito identity becomes inaccessible. You must use AWS Developer credentials to call this API.

    Args:
        identity_id(str): A unique identifier in the format REGION:GUID.
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.
        developer_provider_name(str): The "domain" by which Cognito will refer to your users.
        developer_user_identifier(str): A unique ID used by your backend authentication process to identify a user.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.developer_identity.unlink(
                ctx,
                identity_id=value,
                identity_pool_id=value,
                developer_provider_name=value,
                developer_user_identifier=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.developer_identity.unlink identity_id=value, identity_pool_id=value, developer_provider_name=value, developer_user_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="unlink_developer_identity",
        op_kwargs={
            "IdentityId": identity_id,
            "IdentityPoolId": identity_pool_id,
            "DeveloperProviderName": developer_provider_name,
            "DeveloperUserIdentifier": developer_user_identifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, application_name: str, deployment_group_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more deployment groups.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the applicable IAM user or AWS account.
        deployment_group_names(List): The names of the deployment groups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.get.deployment.group.batch(
                ctx, application_name=value, deployment_group_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.get.deployment.group.batch application_name=value, deployment_group_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="batch_get_deployment_groups",
        op_kwargs={
            "applicationName": application_name,
            "deploymentGroupNames": deployment_group_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, transform_id: str, output_s3_path: str) -> Dict:
    r"""
    **Autogenerated function**

    Begins an asynchronous task to export all labeled data for a particular transform. This task is the only label-related API call that is not part of the typical active learning workflow. You typically use StartExportLabelsTaskRun when you want to work with all of your existing labels at the same time, such as when you want to remove or change labels that were previously submitted as truth. This API operation accepts the TransformId whose labels you want to export and an Amazon Simple Storage Service (Amazon S3) path to export the labels to. The operation returns a TaskRunId. You can check on the status of your task run by calling the GetMLTaskRun API.

    Args:
        transform_id(str): The unique identifier of the machine learning transform.
        output_s3_path(str): The Amazon S3 path where you export the labels.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.export_label_task_run.start(
                ctx, transform_id=value, output_s3_path=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.export_label_task_run.start transform_id=value, output_s3_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="start_export_labels_task_run",
        op_kwargs={"TransformId": transform_id, "OutputS3Path": output_s3_path},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_configuration_name: str,
    domain_name: str = None,
    server_certificate_arns: List = None,
    validation_certificate_arn: str = None,
    authorizer_config: Dict = None,
    service_type: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a domain configuration.

    Args:
        domain_configuration_name(str): The name of the domain configuration. This value must be unique to a region.
        domain_name(str, optional): The name of the domain. Defaults to None.
        server_certificate_arns(List, optional): The ARNs of the certificates that AWS IoT passes to the device during the TLS handshake. Currently you can specify only one certificate ARN. This value is not required for AWS-managed domains. Defaults to None.
        validation_certificate_arn(str, optional): The certificate used to validate the server certificate and prove domain name ownership. This certificate must be signed by a public certificate authority. This value is not required for AWS-managed domains. Defaults to None.
        authorizer_config(Dict, optional): An object that specifies the authorization service for a domain. Defaults to None.
        service_type(str, optional): The type of service delivered by the endpoint.  AWS IoT Core currently supports only the DATA service type. . Defaults to None.
        tags(List, optional): Metadata which can be used to manage the domain configuration.  For URI Request parameters use format: ...key1=value1&key2=value2... For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..." For the cli-input-json file use format: "tags": "key1=value1&key2=value2..." . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.domain_configuration.create(
                ctx, domain_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.domain_configuration.create domain_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_domain_configuration",
        op_kwargs={
            "domainConfigurationName": domain_configuration_name,
            "domainName": domain_name,
            "serverCertificateArns": server_certificate_arns,
            "validationCertificateArn": validation_certificate_arn,
            "authorizerConfig": authorizer_config,
            "serviceType": service_type,
            "tags": tags,
        },
    )


async def delete(hub, ctx, domain_configuration_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified domain configuration.

    Args:
        domain_configuration_name(str): The name of the domain configuration to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.domain_configuration.delete(
                ctx, domain_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.domain_configuration.delete domain_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_domain_configuration",
        op_kwargs={"domainConfigurationName": domain_configuration_name},
    )


async def describe(hub, ctx, domain_configuration_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets summary information about a domain configuration.

    Args:
        domain_configuration_name(str): The name of the domain configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.domain_configuration.describe(
                ctx, domain_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.domain_configuration.describe domain_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_domain_configuration",
        op_kwargs={"domainConfigurationName": domain_configuration_name},
    )


async def list_all(
    hub, ctx, marker: str = None, page_size: int = None, service_type: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of domain configurations for the user. This list is sorted alphabetically by domain configuration name.

    Args:
        marker(str, optional): The marker for the next set of results. Defaults to None.
        page_size(int, optional): The result page size. Defaults to None.
        service_type(str, optional): The type of service delivered by the endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.domain_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.domain_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_domain_configurations",
        op_kwargs={
            "marker": marker,
            "pageSize": page_size,
            "serviceType": service_type,
        },
    )


async def update(
    hub,
    ctx,
    domain_configuration_name: str,
    authorizer_config: Dict = None,
    domain_configuration_status: str = None,
    remove_authorizer_config: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates values stored in the domain configuration. Domain configurations for default endpoints can't be updated.

    Args:
        domain_configuration_name(str): The name of the domain configuration to be updated.
        authorizer_config(Dict, optional): An object that specifies the authorization service for a domain. Defaults to None.
        domain_configuration_status(str, optional): The status to which the domain configuration should be updated. Defaults to None.
        remove_authorizer_config(bool, optional): Removes the authorization configuration from a domain. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.domain_configuration.update(
                ctx, domain_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.domain_configuration.update domain_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_domain_configuration",
        op_kwargs={
            "domainConfigurationName": domain_configuration_name,
            "authorizerConfig": authorizer_config,
            "domainConfigurationStatus": domain_configuration_status,
            "removeAuthorizerConfig": remove_authorizer_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    engine_type: str,
    engine_version: str,
    name: str,
    authentication_strategy: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new configuration for the specified configuration name. Amazon MQ uses the default configuration (the engine type and version).

    Args:
        authentication_strategy(str, optional): Optional. The authentication strategy associated with the configuration. The default is SIMPLE. Defaults to None.
        engine_type(str): Required. The type of broker engine. Currently, Amazon MQ supports ACTIVEMQ and RABBITMQ.
        engine_version(str): Required. The broker engine's version. For a list of supported engine versions, see Supported engines.
        name(str): Required. The name of the configuration. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 1-150 characters long.
        tags(Dict, optional): Create tags when creating the configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.configuration.init.create(
                ctx, engine_type=value, engine_version=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.configuration.init.create engine_type=value, engine_version=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="create_configuration",
        op_kwargs={
            "AuthenticationStrategy": authentication_strategy,
            "EngineType": engine_type,
            "EngineVersion": engine_version,
            "Name": name,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, configuration_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified configuration.

    Args:
        configuration_id(str): The unique ID that Amazon MQ generates for the configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.configuration.init.describe(ctx, configuration_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.configuration.init.describe configuration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="describe_configuration",
        op_kwargs={"ConfigurationId": configuration_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all configurations.

    Args:
        max_results(int, optional): The maximum number of brokers that Amazon MQ can return per page (20 by default). This value must be an integer from 5 to 100. Defaults to None.
        next_token(str, optional): The token that specifies the next page of results Amazon MQ should return. To request the first page, leave nextToken empty. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.configuration.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.configuration.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="list_configurations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, configuration_id: str, data: str, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified configuration.

    Args:
        configuration_id(str): The unique ID that Amazon MQ generates for the configuration.
        data(str): Required. The base64-encoded XML configuration.
        description(str, optional): The description of the configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.configuration.init.update(
                ctx, configuration_id=value, data=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.configuration.init.update configuration_id=value, data=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="update_configuration",
        op_kwargs={
            "ConfigurationId": configuration_id,
            "Data": data,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Applies tags to an existing AWS X-Ray group or sampling rule.

    Args:
        resource_arn(str): The Amazon Resource Number (ARN) of an X-Ray group or sampling rule.
        tags(List): A map that contains one or more tag keys and tag values to attach to an X-Ray group or sampling rule. For more information about ways to use tags, see Tagging AWS resources in the AWS General Reference. The following restrictions apply to tags:   Maximum number of user-applied tags per resource: 50   Maximum tag key length: 128 Unicode characters   Maximum tag value length: 256 Unicode characters   Valid values for key and value: a-z, A-Z, 0-9, space, and the following characters: _ . : / = + - and @   Tag keys and values are case sensitive.   Don't use aws: as a prefix for keys; it's reserved for AWS use. You cannot edit or delete system tags.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from an AWS X-Ray group or sampling rule. You cannot edit or delete system tags (those with an aws: prefix).

    Args:
        resource_arn(str): The Amazon Resource Number (ARN) of an X-Ray group or sampling rule.
        tag_keys(List): Keys for one or more tags that you want to remove from an X-Ray group or sampling rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(
    hub,
    ctx,
    resource_id: str,
    principals: List,
    authentication_token: str = None,
    notification_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a set of permissions for the specified folder or document. The resource permissions are overwritten if the principals already have different permissions.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        resource_id(str): The ID of the resource.
        principals(List): The users, groups, or organization being granted permission.
        notification_options(Dict, optional): The notification options. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.resource.permission.add(
                ctx, resource_id=value, principals=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.resource.permission.add resource_id=value, principals=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="add_resource_permissions",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "ResourceId": resource_id,
            "Principals": principals,
            "NotificationOptions": notification_options,
        },
    )


async def describe_all(
    hub,
    ctx,
    resource_id: str,
    authentication_token: str = None,
    principal_id: str = None,
    limit: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the permissions of a specified resource.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        resource_id(str): The ID of the resource.
        principal_id(str, optional): The ID of the principal to filter permissions by. Defaults to None.
        limit(int, optional): The maximum number of items to return with this call. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.resource.permission.describe_all(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.resource.permission.describe_all resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_resource_permissions",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "ResourceId": resource_id,
            "PrincipalId": principal_id,
            "Limit": limit,
            "Marker": marker,
        },
    )


async def remove(
    hub,
    ctx,
    resource_id: str,
    principal_id: str,
    authentication_token: str = None,
    principal_type: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Removes the permission for the specified principal from the specified resource.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        resource_id(str): The ID of the resource.
        principal_id(str): The principal ID of the resource.
        principal_type(str, optional): The principal type of the resource. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.resource.permission.remove(
                ctx, resource_id=value, principal_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.resource.permission.remove resource_id=value, principal_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="remove_resource_permission",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "ResourceId": resource_id,
            "PrincipalId": principal_id,
            "PrincipalType": principal_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, function_name: str, qualifier: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the provisioned concurrency configuration for a function.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str): The version number or alias name.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.provisioned_concurrency_config.delete(
                ctx, function_name=value, qualifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.provisioned_concurrency_config.delete function_name=value, qualifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_provisioned_concurrency_config",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )


async def get(hub, ctx, function_name: str, qualifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the provisioned concurrency configuration for a function's alias or version.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str): The version number or alias name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.provisioned_concurrency_config.get(
                ctx, function_name=value, qualifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.provisioned_concurrency_config.get function_name=value, qualifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_provisioned_concurrency_config",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )


async def list_all(
    hub, ctx, function_name: str, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of provisioned concurrency configurations for a function.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        marker(str, optional): Specify the pagination token that's returned by a previous request to retrieve the next page of results. Defaults to None.
        max_items(int, optional): Specify a number to limit the number of configurations returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.provisioned_concurrency_config.list_all(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.provisioned_concurrency_config.list_all function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_provisioned_concurrency_configs",
        op_kwargs={
            "FunctionName": function_name,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )


async def put(
    hub, ctx, function_name: str, qualifier: str, provisioned_concurrent_executions: int
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a provisioned concurrency configuration to a function's alias or version.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str): The version number or alias name.
        provisioned_concurrent_executions(int): The amount of provisioned concurrency to allocate for the version or alias.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.provisioned_concurrency_config.put(
                ctx, function_name=value, qualifier=value, provisioned_concurrent_executions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.provisioned_concurrency_config.put function_name=value, qualifier=value, provisioned_concurrent_executions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="put_provisioned_concurrency_config",
        op_kwargs={
            "FunctionName": function_name,
            "Qualifier": qualifier,
            "ProvisionedConcurrentExecutions": provisioned_concurrent_executions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, max_results: int = None, next_token: str = None, vpc_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the ClassicLink DNS support status of one or more VPCs. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide.

    Args:
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        vpc_ids(List, optional): One or more VPC IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.classic_link.dns_support.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.classic_link.dns_support.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_classic_link_dns_support",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "VpcIds": vpc_ids,
        },
    )


async def disable(hub, ctx, vpc_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Disables ClassicLink DNS support for a VPC. If disabled, DNS hostnames resolve to public IP addresses when addressed between a linked EC2-Classic instance and instances in the VPC to which it's linked. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide. You must specify a VPC ID in the request.

    Args:
        vpc_id(str, optional): The ID of the VPC. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.classic_link.dns_support.disable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.classic_link.dns_support.disable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disable_vpc_classic_link_dns_support",
        op_kwargs={"VpcId": vpc_id},
    )


async def enable(hub, ctx, vpc_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Enables a VPC to support DNS hostname resolution for ClassicLink. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide. You must specify a VPC ID in the request.

    Args:
        vpc_id(str, optional): The ID of the VPC. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.classic_link.dns_support.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.classic_link.dns_support.enable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_vpc_classic_link_dns_support",
        op_kwargs={"VpcId": vpc_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    vpc_id: str,
    amazon_provided_ipv6_cidr_block: bool = None,
    cidr_block: str = None,
    ipv6_cidr_block_network_border_group: str = None,
    ipv6_pool: str = None,
    ipv6_cidr_block: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a CIDR block with your VPC. You can associate a secondary IPv4 CIDR block, an Amazon-provided IPv6 CIDR block, or an IPv6 CIDR block from an IPv6 address pool that you provisioned through bring your own IP addresses (BYOIP). The IPv6 CIDR block size is fixed at /56. You must specify one of the following in the request: an IPv4 CIDR block, an IPv6 pool, or an Amazon-provided IPv6 CIDR block. For more information about associating CIDR blocks with your VPC and applicable restrictions, see VPC and subnet sizing in the Amazon Virtual Private Cloud User Guide.

    Args:
        amazon_provided_ipv6_cidr_block(bool, optional): Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IPv6 addresses, or the size of the CIDR block. Defaults to None.
        cidr_block(str, optional): An IPv4 CIDR block to associate with the VPC. Defaults to None.
        vpc_id(str): The ID of the VPC.
        ipv6_cidr_block_network_border_group(str, optional): The name of the location from which we advertise the IPV6 CIDR block. Use this parameter to limit the CIDR block to this location.  You must set AmazonProvidedIpv6CidrBlock to true to use this parameter.  You can have one IPv6 CIDR block association per network border group. Defaults to None.
        ipv6_pool(str, optional): The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block. Defaults to None.
        ipv6_cidr_block(str, optional): An IPv6 CIDR block from the IPv6 address pool. You must also specify Ipv6Pool in the request. To let Amazon choose the IPv6 CIDR block for you, omit this parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.cidr_block.associate(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.cidr_block.associate vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_vpc_cidr_block",
        op_kwargs={
            "AmazonProvidedIpv6CidrBlock": amazon_provided_ipv6_cidr_block,
            "CidrBlock": cidr_block,
            "VpcId": vpc_id,
            "Ipv6CidrBlockNetworkBorderGroup": ipv6_cidr_block_network_border_group,
            "Ipv6Pool": ipv6_pool,
            "Ipv6CidrBlock": ipv6_cidr_block,
        },
    )


async def disassociate(hub, ctx, association_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a CIDR block from a VPC. To disassociate the CIDR block, you must specify its association ID. You can get the association ID by using DescribeVpcs. You must detach or delete all gateways and resources that are associated with the CIDR block before you can disassociate it.  You cannot disassociate the CIDR block with which you originally created the VPC (the primary CIDR block).

    Args:
        association_id(str): The association ID for the CIDR block.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.cidr_block.disassociate(ctx, association_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.cidr_block.disassociate association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_vpc_cidr_block",
        op_kwargs={"AssociationId": association_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(
    hub, ctx, load_balancer_name: str, load_balancer_port: int, ssl_certificate_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the certificate that terminates the specified listener's SSL connections. The specified certificate replaces any prior certificate that was used on the same load balancer and port. For more information about updating your SSL certificate, see Replace the SSL Certificate for Your Load Balancer in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        load_balancer_port(int): The port that uses the specified SSL certificate.
        ssl_certificate_id(str): The Amazon Resource Name (ARN) of the SSL certificate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.listener.ssl_certificate.set(
                ctx, load_balancer_name=value, load_balancer_port=value, ssl_certificate_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.listener.ssl_certificate.set load_balancer_name=value, load_balancer_port=value, ssl_certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="set_load_balancer_listener_ssl_certificate",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "LoadBalancerPort": load_balancer_port,
            "SSLCertificateId": ssl_certificate_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource_arns: List, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified tags to the specified Elastic Load Balancing resource. You can tag your Application Load Balancers, Network Load Balancers, Gateway Load Balancers, target groups, listeners, and rules. Each tag consists of a key and an optional value. If a resource already has a tag with the same key, AddTags updates its value.

    Args:
        resource_arns(List): The Amazon Resource Name (ARN) of the resource.
        tags(List): The tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.tags.add(ctx, resource_arns=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.tags.add resource_arns=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="add_tags",
        op_kwargs={"ResourceArns": resource_arns, "Tags": tags},
    )


async def describe(hub, ctx, resource_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes the tags for the specified Elastic Load Balancing resources. You can describe the tags for one or more Application Load Balancers, Network Load Balancers, Gateway Load Balancers, target groups, listeners, or rules.

    Args:
        resource_arns(List): The Amazon Resource Names (ARN) of the resources. You can specify up to 20 resources in a single call.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.tags.describe(ctx, resource_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.tags.describe resource_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_tags",
        op_kwargs={"ResourceArns": resource_arns},
    )


async def remove(hub, ctx, resource_arns: List, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified tags from the specified Elastic Load Balancing resources. You can remove the tags for one or more Application Load Balancers, Network Load Balancers, Gateway Load Balancers, target groups, listeners, or rules.

    Args:
        resource_arns(List): The Amazon Resource Name (ARN) of the resource.
        tag_keys(List): The tag keys for the tags to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.tags.remove(ctx, resource_arns=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.tags.remove resource_arns=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="remove_tags",
        op_kwargs={"ResourceArns": resource_arns, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    state: str,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of all active sessions (both connected and disconnected) or terminated sessions from the past 30 days.

    Args:
        state(str): The session status to retrieve a list of sessions for. For example, "Active".
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        filters(List, optional): One or more filters to limit the type of sessions returned by the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.session.describe_all(ctx, state=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.session.describe_all state=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_sessions",
        op_kwargs={
            "State": state,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )


async def resume(hub, ctx, session_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Reconnects a session to an instance after it has been disconnected. Connections can be resumed for disconnected sessions, but not terminated sessions.  This command is primarily for use by client machines to automatically reconnect during intermittent network issues. It isn't intended for any other use.

    Args:
        session_id(str): The ID of the disconnected session to resume.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.session.resume(ctx, session_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.session.resume session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="resume_session",
        op_kwargs={"SessionId": session_id},
    )


async def start(
    hub, ctx, target: str, document_name: str = None, parameters: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a connection to a target (for example, an instance) for a Session Manager session. Returns a URL and token that can be used to open a WebSocket connection for sending input and receiving outputs.  Amazon Web Services CLI usage: start-session is an interactive command that requires the Session Manager plugin to be installed on the client machine making the call. For information, see Install the Session Manager plugin for the Amazon Web Services CLI in the Amazon Web Services Systems Manager User Guide. Amazon Web Services Tools for PowerShell usage: Start-SSMSession isn't currently supported by Amazon Web Services Tools for PowerShell on Windows local machines.

    Args:
        target(str): The instance to connect to for the session.
        document_name(str, optional): The name of the SSM document to define the parameters and plugin settings for the session. For example, SSM-SessionManagerRunShell. You can call the GetDocument API to verify the document exists before attempting to start a session. If no document name is provided, a shell to the instance is launched by default. Defaults to None.
        parameters(Dict, optional): Reserved for future use. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.session.start(ctx, target=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.session.start target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="start_session",
        op_kwargs={
            "Target": target,
            "DocumentName": document_name,
            "Parameters": parameters,
        },
    )


async def terminate(hub, ctx, session_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently ends a session and closes the data connection between the Session Manager client and SSM Agent on the instance. A terminated session isn't be resumed.

    Args:
        session_id(str): The ID of the session to terminate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.session.terminate(ctx, session_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.session.terminate session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="terminate_session",
        op_kwargs={"SessionId": session_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update_multiple(hub, ctx, virtual_interface_id: str, mtu: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified attributes of the specified virtual private interface. Setting the MTU of a virtual interface to 9001 (jumbo frames) can cause an update to the underlying physical connection if it wasn't updated to support jumbo frames. Updating the connection disrupts network connectivity for all virtual interfaces associated with the connection for up to 30 seconds. To check whether your connection supports jumbo frames, call DescribeConnections. To check whether your virtual q interface supports jumbo frames, call DescribeVirtualInterfaces.

    Args:
        virtual_interface_id(str): The ID of the virtual private interface.
        mtu(int, optional): The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 9001. The default value is 1500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.virtual.interface.attribute.update_multiple(
                ctx, virtual_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.virtual.interface.attribute.update_multiple virtual_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="update_virtual_interface_attributes",
        op_kwargs={"virtualInterfaceId": virtual_interface_id, "mtu": mtu},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    resource_query: Dict = None,
    tags: Dict = None,
    configuration: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a resource group with the specified name and description. You can optionally include a resource query, or a service configuration. For more information about constructing a resource query, see Create a tag-based group in Resource Groups. For more information about service configurations, see Service configurations for resource groups.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:CreateGroup

    Args:
        name(str): The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each AWS Region in your AWS account.
        description(str, optional): The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces. Defaults to None.
        resource_query(Dict, optional): The resource query that determines which AWS resources are members of this group. For more information about resource queries, see Create a tag-based group in Resource Groups.   A resource group can contain either a ResourceQuery or a Configuration, but not both. . Defaults to None.
        tags(Dict, optional): The tags to add to the group. A tag is key-value pair string. Defaults to None.
        configuration(List, optional): A configuration associates the resource group with an AWS service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For details about the syntax of service configurations, see Service configurations for resource groups.  A resource group can contain either a Configuration or a ResourceQuery, but not both. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="create_group",
        op_kwargs={
            "Name": name,
            "Description": description,
            "ResourceQuery": resource_query,
            "Tags": tags,
            "Configuration": configuration,
        },
    )


async def delete(hub, ctx, group_name: str = None, group: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified resource group. Deleting a resource group does not delete any resources that are members of the group; it only deletes the group structure.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:DeleteGroup

    Args:
        group_name(str, optional): Deprecated - don't use this parameter. Use Group instead. Defaults to None.
        group(str, optional): The name or the ARN of the resource group to delete. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="delete_group",
        op_kwargs={"GroupName": group_name, "Group": group},
    )


async def get(hub, ctx, group_name: str = None, group: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specified resource group.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:GetGroup

    Args:
        group_name(str, optional): Deprecated - don't use this parameter. Use Group instead. Defaults to None.
        group(str, optional): The name or the ARN of the resource group to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="get_group",
        op_kwargs={"GroupName": group_name, "Group": group},
    )


async def list_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing resource groups in your account.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:ListGroups

    Args:
        filters(List, optional): Filters, formatted as GroupFilter objects, that you want to apply to a ListGroups operation.    resource-type - Filter the results to include only those of the specified resource types. Specify up to five resource types in the format AWS::ServiceCode::ResourceType . For example, AWS::EC2::Instance, or AWS::S3::Bucket.    configuration-type - Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:    AWS:EC2::CapacityReservationPool     AWS:EC2::HostManagement     . Defaults to None.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="list_groups",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, group_name: str = None, group: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the description for an existing group. You cannot update the name of a resource group.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:UpdateGroup

    Args:
        group_name(str, optional): Don't use this parameter. Use Group instead. Defaults to None.
        group(str, optional): The name or the ARN of the resource group to modify. Defaults to None.
        description(str, optional): The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="update_group",
        op_kwargs={"GroupName": group_name, "Group": group, "Description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    configuration_aggregator_name: str,
    resource_type: str,
    filters: Dict = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a resource type and returns a list of resource identifiers that are aggregated for a specific resource type across accounts and regions. A resource identifier includes the resource type, ID, (if available) the custom resource name, source account, and source region. You can narrow the results to include only resources that have specific resource IDs, or a resource name, or source account ID, or source region. For example, if the input consists of accountID 12345678910 and the region is us-east-1 for resource type AWS::EC2::Instance then the API returns all the EC2 instance identifiers of accountID 12345678910 and region us-east-1.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator. .
        resource_type(str): The type of resources that you want AWS Config to list in the response.
        filters(Dict, optional): Filters the results based on the ResourceFilters object. Defaults to None.
        limit(int, optional): The maximum number of resource identifiers returned on each page. You cannot specify a number greater than 100. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.discovered_resource.init.list_all(
                ctx, configuration_aggregator_name=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.discovered_resource.init.list_all configuration_aggregator_name=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="list_aggregate_discovered_resources",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "ResourceType": resource_type,
            "Filters": filters,
            "Limit": limit,
            "NextToken": next_token,
        },
    )
